@@ -35,4 +35,4 @@
 #' \url{http://data.trilliumtransit.com/gtfs/duke-nc-us/duke-nc-us.zip}. 
 #' @docType data
 #' @seealso read_gtfs
-"gtfs_obj"
\ No newline at end of file
+"gtfs_duke"
\ No newline at end of file
