@@ -1,14 +1,14 @@
 #' Function that creates gtfs meta data
 #' @return Environment with gtfs data.
 #' @noRd
-
 get_gtfs_meta <- function() {
 
   # required files ----------------------------------------------------------
 
   # agency
   assign("agency", list())
-  agency$field <- c("agency_id", "agency_name", "agency_url", "agency_timezone", "agency_lang", "agency_phone", "agency_fare_url", "agency_email")
+  agency$field <- c("agency_id", "agency_name", "agency_url", "agency_timezone", 
+                    "agency_lang", "agency_phone", "agency_fare_url", "agency_email")
   agency$field_spec <- c("opt", "req", "req", "req", "opt", "opt", "opt", "opt")
   names(agency$field_spec) <- agency$field
   agency$coltype <- rep("c", 8)
@@ -16,23 +16,22 @@ get_gtfs_meta <- function() {
   
   # stops
   assign("stops", list())
-  stops$field <- c("stop_id", "stop_code", "platform_code", 
-                   "stop_name", "stop_desc", "stop_lat", 
-                   "stop_lon", "zone_id", "stop_url", 
+  stops$field <- c("stop_id", "stop_code", "stop_name", 
+                   "stop_desc", "stop_lat", "stop_lon", 
+                   "zone_id", "stop_url", 
                    "location_type", "parent_station", 
-                   "stop_timezone", "wheelchair_boarding")
-  stops$field_spec <- c("req", "opt", "opt", 
-                        "req", "opt", "req", 
-                        "req", "opt", "opt", 
-                        "opt", "opt", "opt", 
-                        "opt")
+                   "stop_timezone", "wheelchair_boarding",
+                   "level_id", "platform_code")
+  stops$field_spec <- c("req", "opt", "req", "opt",
+                        "req", "req", 
+                        rep("opt", 8))
   names(stops$field_spec) <- stops$field
   stops$coltype <- rep("c", length(stops$field))
   stops$coltype[which(stops$field %in% 
                         c("stop_lat", "stop_lon"))] <- "d" # double
   stops$coltype[which(stops$field %in% 
                         c("location_type",
-                          "wheelchair_boarding"))] <- "i" #integers
+                          "wheelchair_boarding"))] <- "i" # integers
   stops$file_spec <- "req"
   
   # routes
@@ -40,14 +39,17 @@ get_gtfs_meta <- function() {
   routes$field <- c("route_id", "agency_id", "route_short_name", 
                     "route_long_name", "route_desc", "route_type", 
                     "route_url", "route_color", 
-                    "route_text_color", "route_sort_order")
+                    "route_text_color", "route_sort_order",
+                    "continuous_pickup", "continuous_drop_off")
   routes$field_spec <- c("req", "opt", "req", 
                          "req", "opt", "req", 
                          "opt", "opt", "opt", 
-                         "opt")
+                         "opt", "opt", "opt")
   names(routes$field_spec) <- routes$field
   routes$coltype <- rep("c", length(routes$field))
-  routes$coltype[routes$field %in% c("route_type", "route_sort_order")] <- "i"
+  routes$coltype[routes$field %in% c("route_type", "route_sort_order",
+                                     "continuous_pickup", 
+                                     "continuous_drop_off")] <- "i"
   routes$file_spec <- "req"
   
   # trips
@@ -72,19 +74,19 @@ get_gtfs_meta <- function() {
                         "departure_time", 
                         "stop_id", "stop_sequence", 
                         "stop_headsign", "pickup_type", 
-                        "drop_off_type", "shape_dist_traveled", 
+                        "drop_off_type", "continuous_pickup", 
+                        "continuous_drop_off", "shape_dist_traveled", 
                         "timepoint")
   stop_times$field_spec <- c("req", "req", "req", 
                              "req", "req", "opt", 
                              "opt", "opt", "opt", 
-                             "opt")
+                             "opt", "opt", "opt")
   names(stop_times$field_spec) <- stop_times$field
   stop_times$coltype <- rep("c", length(stop_times$field))
   stop_times$coltype[stop_times$field 
-                     %in% c("stop_sequence", 
-                            "pickup_type", 
-                            "drop_off_type", 
-                            "timepoint")] <- "i"
+                     %in% c("stop_sequence", "pickup_type", 
+                            "drop_off_type", "continuous_pickup", 
+                            "continuous_drop_off","timepoint")] <- "i"
   stop_times$coltype[stop_times$field %in% 
                        c("shape_dist_traveled")] <- "d"
   stop_times$file_spec <- "req"
@@ -254,84 +256,3 @@ get_gtfs_meta <- function() {
                   "opt", "opt",  "opt"))
   return(meta)
 }
-
-get_gtfs_plus_meta <- function() {
-  # calendar_attributes
-  assign("calendar_attributes", list())
-  calendar_attributes$field <- c("service_id", "service_description")
-  calendar_attributes$field_spec <- rep("req", times = 2)
-  calendar_attributes$coltype <- c("c", "c")
-  
-  # directions
-  assign("directions", list())
-  directions$field <- c("route_id", "direction_id", "direction")
-  directions$field_spec <- rep("req", times = 3)
-  directions$coltype <- c("c", "i", "c")
-  
-  # fare_rider_categories
-  assign("fare_rider_categories", list())
-  fare_rider_categories$field <- c("fare_id", "rider_category_id", "price")
-  fare_rider_categories$field_spec <- c("req", "req", "req")
-  fare_rider_categories$coltype <- c("c", "c", "d")
-  
-  # farezone_attributes
-  assign("farezone_attributes", list())
-  farezone_attributes$field <- c("zone_id", "zone_name")
-  farezone_attributes$field_spec <- c("req", "req")
-  farezone_attributes$coltype <- rep("c", length(farezone_attributes$field))
-  
-  # rider_categories
-  assign("rider_categories", list())
-  rider_categories$field <- c("rider_category_id", "rider_category_description")
-  rider_categories$field_spec <- c("req", "req")
-  rider_categories$coltype <- rep("c", length(rider_categories$field))
-  
-  # route_directions
-  assign("route_directions", list())
-  route_directions$field <- c("route_id", "direction_id", "direction_name")
-  route_directions$field_spec <- rep("req", length(route_directions$field))
-  route_directions$coltype <- rep("c", length(route_directions$field))
-  route_directions$coltype[route_directions$field %in% c("direction_id")] <- "i"
-  
-  # stop_attributes
-  assign("stop_attributes", list())
-  stop_attributes$field <- c("stop_id", "stop_city")
-  stop_attributes$field_spec <- c("req", "req")
-  stop_attributes$coltype <- c("c", "c")
-  
-  # timetable_stop_order
-  assign("timetable_stop_order", list())
-  timetable_stop_order$field <- c("timetable_id", "stop_id",
-                                  "stop_sequence", "stop_name",
-                                  "connected_routes")
-  timetable_stop_order$field_spec <- 
-    rep("req", length(timetable_stop_order$field))
-  timetable_stop_order$field_spec[timetable_stop_order$field %in% 
-                                    c("stop_name", "connected_routes")] <- "opt"
-  timetable_stop_order$coltype <- rep("c", 
-                                      length(timetable_stop_order$field))
-  timetable_stop_order$coltype[timetable_stop_order$field %in% 
-                                 c("stop_sequence")] <- "i"
-  
-  # timetables
-  assign("timetables", list())
-  timetables$field <- c("timetable_id", "route_id",
-                        "direction_id", "start_date",
-                        "end_date", "monday", "tuesday",
-                        "wednesday", "thursday", "friday",
-                        "saturday", "sunday", "route_label",
-                        "service_notes", "direction_label",
-                        "orientation")
-  timetables$field_spec <- rep("req", length(timetables$field))
-  timetables$field_spec[timetables$field %in% 
-                          c("route_label","service_notes",
-                            "direction_label","orientation")] <- "opt"
-  timetables$coltype <- rep("c", length(timetables$field))
-  timetables$coltype[timetables$field %in% 
-                       c("direction_id", "monday",
-                         "tuesday", "wednesday", "thursday",
-                         "friday", "saturday", "sunday")] <- "i"
-  
-  environment()
-}
-
