@@ -7,7 +7,7 @@ create_empty_gtfs_obj <- function() {
   return(g)
 }
 
-test_that("gtfs_set_hms_times() works with valid data", {
+test_that("set_hms_times() works with valid data", {
   gtest <- create_empty_gtfs_obj()
   gtest$stop_times <- dplyr::tibble(
     arrival_time = c("08:00:00", "14:00:00", "26:10:00"),
@@ -17,7 +17,7 @@ test_that("gtfs_set_hms_times() works with valid data", {
     end_time = c("12:00:00")
   )
 
-  gtest <- gtfs_set_hms_times(gtest)  
+  gtest <- set_hms_times(gtest)  
   
   expect_is(gtest$stop_times$arrival_time_hms, "hms")
   expect_is(gtest$stop_times$departure_time_hms, "hms")
@@ -33,7 +33,7 @@ test_that("gtfs_set_hms_times() works with valid data", {
   expect_is(gtest$frequencies$end_time, "character")
 })
 
-test_that("get_date_service_table() uses the right dates", {
+test_that("set_date_service_table() uses the right dates", {
   gtest <- create_empty_gtfs_obj()
   gtest$calendar <- dplyr::tibble(
     service_id = "s1",
@@ -47,14 +47,14 @@ test_that("get_date_service_table() uses the right dates", {
     start_date = lubridate::ymd("20180101"), # monday
     end_date = lubridate::ymd("20180131")) # wednesday
 
-  date_service <- tidytransit:::get_date_service_table(gtest)
+  date_service <- tidytransit::set_date_service_table(gtest)$.$date_service_table
   
   expect_true(lubridate::ymd("20180101") %in% date_service$date)
   expect_false(lubridate::ymd("20180102") %in% date_service$date)
   expect_true(lubridate::ymd("20180131") %in% date_service$date)
 })
 
-test_that("get_date_service_table() works with additions and exceptions", { 
+test_that("set_date_service_table() works with additions and exceptions", { 
   gtest <- create_empty_gtfs_obj()
   gtest$calendar <- dplyr::tibble(
     service_id = c("wdays", "wend"),
@@ -75,7 +75,7 @@ test_that("get_date_service_table() works with additions and exceptions", {
     exception_type = c(2, 1)
   )
   
-  date_service <- tidytransit:::get_date_service_table(gtest)
+  date_service <- tidytransit::set_date_service_table(gtest)$.$date_service_table
   
   # exception
   mar14 <- date_service[
